"""
# File       : __config__.py
# Time       ：2024/8/14 上午10:36
# Author     ：xuewei zhang
# Email      ：shuiheyangguang@gmail.com
# version    ：python 3.12
# Description：
"""
api_key = "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"
