"""
# File       : plp_install.py
# Time       ：2024/7/29 上午11:05
# Author     ：xxxx
# Email      ：shuiheyangguang@gmail.com
# version    ：python 3.12
# Description：


# yolo 依赖的包
xlwt
psutil
ultralytics
opencv-python
matplotlib
tqdm
pycocotools

# 讯飞星火大模型依赖的包
websocket-client
openpyxl
openai

# 依赖的其他包，例如：'requests>=2.0.0'
# nlp预处理
emoji
jieba

# Claude api调用依赖包
anthropic

"""
