appid = "5a921ed1"
api_secret = "ed4211f7f00494a59679474004ac6029"
api_key = "b96ff33516c84e865a7cd06c0759691c"  # 位移


self_model_serviceId = "xscnllama2"
self_model_ws_url = "wss://xingcheng-api.cn-huabei-1.xf-yun.com/v1.1/chat"
